CSRF — bodhi 4.0.0 documentation

# CSRF

## Csrf service at /csrf

CSRF Token

### GET

Accepted content types:

- text/html

Return a plain string CSRF token.

Returns:
  basestring: A CSRF token.

Response: string

### GET

Accepted content types:

- application/json
- text/json

Return a JSON string containing a CSRF token, in a key called csrf_token.

Returns:
  basestring: A JSON string with a key csrf_token that references a CSRF token.

Response: json